@@ -176,15 +176,17 @@ void on_ng_launch_clicked                   (GtkButton       *button,
 	GtkWidget	*w = NULL,
 			*romlist = glade_xml_get_widget(glade, "ng_romlist"),
 			*mainwindow = glade_xml_get_widget(glade, "mainwindow");
-	const char*	wnames[2] = { "ng_sound", "ng_double" };
-	gint	flags[3] = { TRUE, TRUE };
+	const char	*wname = "ng_sound",
+	      		*wbios = "ng_bios";
+	gboolean use_sound = FALSE;
 	gint	i = 0,
 		status = 0;
 
-	for(i=0;i<2;++i){
-		w=glade_xml_get_widget(glade, wnames[i]);
-		if(w){ flags[i] = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w)); }//if
-	}//for
+	w=glade_xml_get_widget(glade, wname);
+	if(w){ use_sound = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w)); }//if
+
+	w = glade_xml_get_widget(glade, wbios);
+	if(w){ biospath = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(w)); }
 
 	romname = gtk_combo_box_get_active_text(GTK_COMBO_BOX(romlist));
 
@@ -192,7 +194,7 @@ void on_ng_launch_clicked                   (GtkButton       *button,
 	hildon_banner_show_information(GTK_WIDGET(hildonwindow), NULL, _("Launching gngeo"));
 #endif
 
-	status = launch_gngeo(romname, biospath, flags[0], flags[1]);
+	status = launch_gngeo(romname, biospath, use_sound);
 
 	if(status<0){
 		show_error_dialog(mainwindow,_("Unable to launch gngeo"));
