@@ -55,7 +55,7 @@ xmaeme_init() {
 		*emulators[num_romtypes] = {	"xmame",
 						"fceu",
 						"vba",
-						"gngeoNOTREADYYET" },
+						"gngeo" },
 		*tabs[num_romtypes] = {	"mame_panel",
 					"nes_panel",
 					"gba_panel",
@@ -84,6 +84,8 @@ xmaeme_init() {
   gtk_widget_reparent(GTK_WIDGET(notebook), GTK_WIDGET(hildonwindow));
   g_signal_connect ((gpointer) hildonwindow, "key_press_event", G_CALLBACK (key_press_cb), (gpointer)hildonwindow);
 
+  gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(glade_xml_get_widget(glade, "ng_bios")), "/media/mmc1/roms/neogeo/bios");
+
   /// Set up HildonNumberEditors
   for(i=0; i<NUM_SPINS; ++i) {
 	  name = g_strdup_printf("%s%s", spins[i], "_hildon");
