@@ -4,6 +4,7 @@
 #include <glib.h>
 
 #include "util.h"
+#include "xmame.h"
 
 
 #define NUM_EXTENSIONS 3
@@ -24,6 +25,16 @@ GList* get_installed_roms(xmaeme_rom_type romtype){
 	gboolean mame_rom = FALSE;
 
 	if(XMAEME_ROMTYPE_MAME == romtype){
+		int j = 0;
+		for(; j<XMAME_RC_PATH_COUNT; ++j) {
+			currpath = xmame_get_rompath_from_xmamerc(XMAME_RC_PATHS[j]);
+			if(currpath) {
+				tmp = get_installed_roms_in_path(currpath, romtype);
+				rv = g_list_concat(rv,tmp);
+				g_free(currpath);
+			}// got another rompath
+		}// check xmamercs for rompaths
+
 		mame_rom = TRUE;
 	}//MAME!
 
